package com.ff.common.service.impl;

import java.util.List;
import com.ff.base.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ff.common.mapper.LangMapper;
import com.ff.common.domain.Lang;
import com.ff.common.service.ILangService;

/**
 * 系统语种管理 Service业务层处理
 *
 * @author shi
 * @date 2025-02-10
 */
@Service
public class LangServiceImpl implements ILangService
{
    @Autowired
    private LangMapper langMapper;

    /**
     * 查询系统语种管理 
     *
     * @param id 系统语种管理 主键
     * @return 系统语种管理 
     */
    @Override
    public Lang selectLangById(Long id)
    {
        return langMapper.selectLangById(id);
    }

    /**
     * 查询系统语种管理 列表
     *
     * @param lang 系统语种管理 
     * @return 系统语种管理 
     */
    @Override
    public List<Lang> selectLangList(Lang lang)
    {
        return langMapper.selectLangList(lang);
    }

    /**
     * 新增系统语种管理 
     *
     * @param lang 系统语种管理 
     * @return 结果
     */
    @Override
    public int insertLang(Lang lang)
    {
        lang.setCreateTime(DateUtils.getNowDate());
        return langMapper.insertLang(lang);
    }

    /**
     * 修改系统语种管理 
     *
     * @param lang 系统语种管理 
     * @return 结果
     */
    @Override
    public int updateLang(Lang lang)
    {
        lang.setUpdateTime(DateUtils.getNowDate());
        return langMapper.updateLang(lang);
    }

    /**
     * 批量删除系统语种管理 
     *
     * @param ids 需要删除的系统语种管理 主键
     * @return 结果
     */
    @Override
    public int deleteLangByIds(Long[] ids)
    {
        return langMapper.deleteLangByIds(ids);
    }

    /**
     * 删除系统语种管理 信息
     *
     * @param id 系统语种管理 主键
     * @return 结果
     */
    @Override
    public int deleteLangById(Long id)
    {
        return langMapper.deleteLangById(id);
    }
}
